# ---------------------------------------------------------------------
#
# Copyright (c) CREATIS (Centre de Recherche en Acquisition et Traitement de l'Image 
#                        pour la Sant)
# Authors : Eduardo Davila, Frederic Cervenansky, Claire Mouton
# Previous Authors : Laurent Guigues, Jean-Pierre Roux
# CreaTools website : www.creatis.insa-lyon.fr/site/fr/creatools_accueil
#
#  This software is governed by the CeCILL-B license under French law and 
#  abiding by the rules of distribution of free software. You can  use, 
#  modify and/ or redistribute the software under the terms of the CeCILL-B 
#  license as circulated by CEA, CNRS and INRIA at the following URL 
#  http://www.cecill.info/licences/Licence_CeCILL-B_V1-en.html 
#  or in the file LICENSE.txt.
#
#  As a counterpart to the access to the source code and  rights to copy,
#  modify and redistribute granted by the license, users are provided only
#  with a limited warranty  and the software's author,  the holder of the
#  economic rights,  and the successive licensors  have only  limited
#  liability. 
#
#  The fact that you are presently reading this means that you have had
#  knowledge of the CeCILL-B license and that you accept its terms.
# ------------------------------------------------------------------------ */ 


# - Find a library installation or build tree.
# 
# The following variables are set if bbgdcmvtk is found.  
# If bbgdcmvtk is not found, bbgdcmvtk_FOUND is set to false.
#  bbgdcmvtk_FOUND         - Set to true when bbgdcmvtk is found.
#  bbgdcmvtk_USE_FILE      - CMake file to use bbgdcmvtk.
#  bbgdcmvtk_MAJOR_VERSION - The bbgdcmvtk major version number.
#  bbgdcmvtk_MINOR_VERSION - The bbgdcmvtk minor version number 
#                       (odd non-release).
#  bbgdcmvtk_BUILD_VERSION - The bbgdcmvtk patch level 
#                       (meaningless for odd minor).
#  bbgdcmvtk_INCLUDE_DIRS  - Include directories for bbgdcmvtk
#  bbgdcmvtk_LIBRARY_DIRS  - Link directories for bbgdcmvtk libraries
#  bbgdcmvtk_LIBRARIES     - List of libraries to link against
#
# The following cache entries must be set by the user to locate bbgdcmvtk:
#  bbgdcmvtk_DIR  - The directory containing bbgdcmvtkConfig.cmake.  
#             This is either the root of the build tree,
#             or the lib/bbgdcmvtk directory.  This is the 
#             only cache entry.


# Construct consitent error messages for use below.
SET(bbgdcmvtk_DIR_DESCRIPTION "directory containing bbgdcmvtkConfig.cmake.  This is either the root of the build tree, or PREFIX/lib/bbgdcmvtk for an installation.")
SET(bbgdcmvtk_NOT_FOUND_MESSAGE "bbgdcmvtk not found.  Set the bbgdcmvtk_DIR cmake cache entry to the ${bbgdcmvtk_DIR_DESCRIPTION}")

# Search only if the location is not already known.
IF(NOT bbgdcmvtk_DIR)
  # Get the system search path as a list.
  IF(UNIX)
    STRING(REGEX MATCHALL "[^:]+" bbgdcmvtk_DIR_SEARCH1 "$ENV{PATH}")
  ELSE(UNIX)
    STRING(REGEX REPLACE "\\\\" "/" bbgdcmvtk_DIR_SEARCH1 "$ENV{PATH}")
  ENDIF(UNIX)
  STRING(REGEX REPLACE "/;" ";" bbgdcmvtk_DIR_SEARCH2 "${bbgdcmvtk_DIR_SEARCH1}")

  # Construct a set of paths relative to the system search path.
  SET(bbgdcmvtk_DIR_SEARCH "")
  FOREACH(dir ${bbgdcmvtk_DIR_SEARCH2})
    SET(bbgdcmvtk_DIR_SEARCH ${bbgdcmvtk_DIR_SEARCH}
      ${dir}/../lib/lib64/creatools/bbgdcmvtk
      )
  ENDFOREACH(dir)

  #
  # Look for an installation or build tree.
  #
  FIND_PATH(bbgdcmvtk_DIR Usebbgdcmvtk.cmake
    # Look for an environment variable bbgdcmvtk_DIR.
    $ENV{bbgdcmvtk_DIR}

    # Look in places relative to the system executable search path.
    ${bbgdcmvtk_DIR_SEARCH}

    # Look in standard WIN install locations.
    "$ENV{ProgramFiles}/bbgdcmvtk"

    # Look in standard UNIX install locations.
    /usr/local/lib64/creatools/bbgdcmvtk
    /usr/lib64/creatools/bbgdcmvtk

    # Read from the CMakeSetup registry entries.  It is likely that
    # bbgdcmvtk will have been recently built.
    [HKEY_CURRENT_USER\\Software\\Kitware\\CMakeSetup\\Settings\\StartPath;WhereBuild1]
    [HKEY_CURRENT_USER\\Software\\Kitware\\CMakeSetup\\Settings\\StartPath;WhereBuild2]
    [HKEY_CURRENT_USER\\Software\\Kitware\\CMakeSetup\\Settings\\StartPath;WhereBuild3]
    [HKEY_CURRENT_USER\\Software\\Kitware\\CMakeSetup\\Settings\\StartPath;WhereBuild4]
    [HKEY_CURRENT_USER\\Software\\Kitware\\CMakeSetup\\Settings\\StartPath;WhereBuild5]
    [HKEY_CURRENT_USER\\Software\\Kitware\\CMakeSetup\\Settings\\StartPath;WhereBuild6]
    [HKEY_CURRENT_USER\\Software\\Kitware\\CMakeSetup\\Settings\\StartPath;WhereBuild7]
    [HKEY_CURRENT_USER\\Software\\Kitware\\CMakeSetup\\Settings\\StartPath;WhereBuild8]
    [HKEY_CURRENT_USER\\Software\\Kitware\\CMakeSetup\\Settings\\StartPath;WhereBuild9]
    [HKEY_CURRENT_USER\\Software\\Kitware\\CMakeSetup\\Settings\\StartPath;WhereBuild10]

    # Help the user find it if we cannot.
    DOC "The ${bbgdcmvtk_DIR_DESCRIPTION}"
  )
ENDIF(NOT bbgdcmvtk_DIR)

# If bbgdcmvtk was found, load the configuration file to get the rest of the
# settings.
IF(bbgdcmvtk_DIR)
  # Make sure the bbgdcmvtkConfig.cmake file exists in the directory provided.
  IF(EXISTS ${bbgdcmvtk_DIR}/bbgdcmvtkConfig.cmake)

    # We found bbgdcmvtk.  Load the settings.
    SET(bbgdcmvtk_FOUND 1)
    INCLUDE(${bbgdcmvtk_DIR}/bbgdcmvtkConfig.cmake)

  ENDIF(EXISTS ${bbgdcmvtk_DIR}/bbgdcmvtkConfig.cmake)
ELSE(bbgdcmvtk_DIR)
  # We did not find bbgdcmvtk.
  SET(bbgdcmvtk_FOUND 0)
ENDIF(bbgdcmvtk_DIR)

#-----------------------------------------------------------------------------
IF(NOT bbgdcmvtk_FOUND)
  # bbgdcmvtk not found, explain to the user how to specify its location.
  IF(NOT bbgdcmvtk_FIND_QUIETLY)
    MESSAGE(FATAL_ERROR ${bbgdcmvtk_NOT_FOUND_MESSAGE})
  ELSE(NOT bbgdcmvtk_FIND_QUIETLY)
    IF(bbgdcmvtk_FIND_REQUIRED)
      MESSAGE(FATAL_ERROR ${bbgdcmvtk_NOT_FOUND_MESSAGE})
    ENDIF(bbgdcmvtk_FIND_REQUIRED)
  ENDIF(NOT bbgdcmvtk_FIND_QUIETLY)
ENDIF(NOT bbgdcmvtk_FOUND)
